==> temando-module-shipping-m2-1.4.1.zip: ViewModel/Batch/BatchDetails.php <==
<?php
/**
 * Refer to LICENSE.txt distributed with the Temando Shipping module for notice of license
 */
namespace Temando\Shipping\ViewModel\Batch;

use Magento\Framework\DataObjectFactory;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Magento\Sales\Api\Data\OrderAddressInterfaceFactory;
use Magento\Sales\Api\Data\ShipmentItemInterface;
use Magento\Sales\Model\Order\Address;
use Magento\Sales\Model\Order\Shipment;
use Temando\Shipping\Model\BatchInterface;
use Temando\Shipping\Model\BatchProviderInterface;
use Temando\Shipping\ViewModel\DataProvider\BatchUrl;
use Temando\Shipping\ViewModel\DataProvider\OrderAddress as AddressRenderer;
use Temando\Shipping\ViewModel\DataProvider\OrderDate;
use Temando\Shipping\ViewModel\DataProvider\OrderUrl;

/**
 * View model for batch details page.
 *
 * @package Temando\Shipping\ViewModel
 * @author  Rhodri Davies <rhodri.davies@temando.com>
 * @license https://opensource.org/licenses/osl-3.0.php Open Software License (OSL 3.0)
 * @link    https://www.temando.com/
 */
class BatchDetails implements ArgumentInterface
{
    /**
     * @var BatchProviderInterface
     */
    private $batchProvider;

    /**
     * @var OrderDate
     */
    private $orderDate;

    /**
     * @var BatchUrl
     */
    private $batchUrl;

    /**
     * @var OrderUrl
     */
    private $orderUrl;

    /**
     * @var DataObjectFactory
     */
    private $dataObjectFactory;

    /**
     * @var AddressRenderer
     */
    private $addressRenderer;

    /**
     * @var OrderAddressInterfaceFactory
     */
    private $addressFactory;

    /**
     * BatchDetails constructor.
     * @param BatchProviderInterface $batchProvider
     * @param OrderDate $orderDate
     * @param BatchUrl $batchUrl
     * @param OrderUrl $orderUrl
     * @param DataObjectFactory $dataObjectFactory
     * @param AddressRenderer $addressRenderer
     * @param OrderAddressInterfaceFactory $orderAddressInterfaceFactory
     */
    public function __construct(
        BatchProviderInterface $batchProvider,
        OrderDate $orderDate,
        BatchUrl $batchUrl,
        OrderUrl $orderUrl,
        DataObjectFactory $dataObjectFactory,
        AddressRenderer $addressRenderer,
        OrderAddressInterfaceFactory $orderAddressInterfaceFactory
    ) {
        $this->batchProvider = $batchProvider;
        $this->orderDate = $orderDate;
        $this->batchUrl = $batchUrl;
        $this->orderUrl = $orderUrl;
        $this->dataObjectFactory = $dataObjectFactory;
        $this->addressRenderer = $addressRenderer;
        $this->addressFactory = $orderAddressInterfaceFactory;
    }

    /**
     * @return \Magento\Framework\DataObject|null
     */
    public function getBatch()
    {
        /** @var \Temando\Shipping\Model\Batch $batch */
        $batch = $this->batchProvider->getBatch();
        return $batch;
    }

    /**
     * @param string $date
     * @return \DateTime
     */
    public function getDate(string $date): \DateTime
    {
        return $this->orderDate->getDate($date);
    }

    /**
     * Obtain batch create url
     *
     * @return string
     */
    public function getNewActionUrl(): string
    {
        return $this->batchUrl->getNewActionUrl();
    }

    /**
     * Obtain batch listing url
     *
     * @return string
     */
    public function getListActionUrl(): string
    {
        return $this->batchUrl->getListActionUrl();
    }

    /**
     * Obtain url for troubleshooting failed batches
     *
     * @return string
     */
    public function getSolveUrl(): string
    {
        return $this->batchUrl->getSolveActionUrl([
            BatchInterface::BATCH_ID => $this->batchProvider->getBatch()->getBatchId(),
        ]);
    }

    /**
     * @param string $orderId
     * @return string
     */
    public function getOrderViewUrl(string $orderId): string
    {
        return $this->orderUrl->getViewActionUrl(['order_id' => $orderId]);
    }

    /**
     * @param $extShipmentId
     * @return  \Magento\Sales\Api\Data\OrderInterface | null
     */
    private function getSalesShipmentOrder($extShipmentId)
    {
        $orders = $this->batchProvider->getOrders();
        if (isset($orders[$extShipmentId])) {
            return $orders[$extShipmentId];
        }

        return null;
    }

    /**
     * Returns ShipmentInfo based on extShipmentId.
     *
     * fixme(nr): replace by some proper piece of software
     *
     * @param string $extShipmentId
     * @return \Magento\Framework\DataObject
     */
    public function getShipmentInfoForGrid($extShipmentId)
    {
        $info = [];
        $order = $this->getSalesShipmentOrder($extShipmentId);
        if ($order) {
            /** @var Shipment $shipment */
            $shipment = $order->getShipmentsCollection()->getFirstItem();
            /** @var Address $shippingAddress */
            $shippingAddress = $shipment->getShippingAddress();
            $formattedShippingAddress = $this->addressRenderer->getFormattedAddress($shipment->getShippingAddress());
            $itemsInfo = $this->getItemsOrderedInfo($shipment->getItems());
            $info = [
                'shipment_id' => $shipment->getId(),
                'ship_to_name' => $shippingAddress->getFirstname() . ' ' . $shippingAddress->getLastname(),
                'destination_address' => $formattedShippingAddress,
                'items_ordered' => $itemsInfo,
            ];
        }

        $shipmentInfo = $this->dataObjectFactory->create(['data' => $info]);

        return $shipmentInfo;
    }

    /**
     * @param ShipmentItemInterface[] $items
     * @return string
     */
    private function getItemsOrderedInfo($items)
    {
        $info = '';
        foreach ($items as $item) {
            $info .= $item->getName() . ' x ' . (int) $item->getQty() . '<br>';
        }

        return $info;
    }
}

==> temando-module-shipping-m2-1.6.1.zip: ViewModel/Batch/BatchDetails.php <==
<?php
/**
 * Refer to LICENSE.txt distributed with the Temando Shipping module for notice of license
 */
namespace Temando\Shipping\ViewModel\Batch;

use Magento\Framework\DataObject;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\Block\ArgumentInterface;
use Temando\Shipping\Model\BatchInterface;
use Temando\Shipping\Model\BatchProviderInterface;
use Temando\Shipping\Model\Location\OrderAddressFactory;
use Temando\Shipping\Model\Shipment\LocationInterface;
use Temando\Shipping\Model\Shipment\ShipmentItemInterface;
use Temando\Shipping\Model\Shipment\ShipmentSummaryInterface;
use Temando\Shipping\ViewModel\DataProvider\BatchUrl;
use Temando\Shipping\ViewModel\DataProvider\OrderAddress as AddressRenderer;
use Temando\Shipping\ViewModel\DataProvider\OrderDate;

/**
 * View model for batch details page.
 *
 * @package Temando\Shipping\ViewModel
 * @author  Rhodri Davies <rhodri.davies@temando.com>
 * @license https://opensource.org/licenses/osl-3.0.php Open Software License (OSL 3.0)
 * @link    https://www.temando.com/
 */
class BatchDetails implements ArgumentInterface
{
    /**
     * @var BatchProviderInterface
     */
    private $batchProvider;

    /**
     * @var OrderDate
     */
    private $orderDate;

    /**
     * @var BatchUrl
     */
    private $batchUrl;

    /**
     * @var OrderAddressFactory
     */
    private $addressFactory;

    /**
     * @var AddressRenderer
     */
    private $addressRenderer;

    /**
     * @var UrlInterface
     */
    private $urlBuilder;

    /**
     * BatchDetails constructor.
     *
     * @param BatchProviderInterface $batchProvider
     * @param OrderDate $orderDate
     * @param BatchUrl $batchUrl
     * @param OrderAddressFactory $addressFactory
     * @param AddressRenderer $addressRenderer
     * @param UrlInterface $urlBuilder
     */
    public function __construct(
        BatchProviderInterface $batchProvider,
        OrderDate $orderDate,
        BatchUrl $batchUrl,
        OrderAddressFactory $addressFactory,
        AddressRenderer $addressRenderer,
        UrlInterface $urlBuilder
    ) {
        $this->batchProvider = $batchProvider;
        $this->orderDate = $orderDate;
        $this->batchUrl = $batchUrl;
        $this->addressFactory = $addressFactory;
        $this->addressRenderer = $addressRenderer;
        $this->urlBuilder = $urlBuilder;
    }

    /**
     * Obtain the current batch entity.
     *
     * @return \Magento\Framework\DataObject|null
     */
    public function getBatch()
    {
        /** @var \Temando\Shipping\Model\Batch $batch */
        $batch = $this->batchProvider->getBatch();
        return $batch;
    }

    /**
     * Obtain order date.
     *
     * @param string $date
     * @return \DateTime
     */
    public function getDate(string $date): \DateTime
    {
        return $this->orderDate->getDate($date);
    }

    /**
     * Obtain batch create url
     *
     * @return string
     */
    public function getNewActionUrl(): string
    {
        return $this->batchUrl->getNewActionUrl();
    }

    /**
     * Obtain batch listing url
     *
     * @return string
     */
    public function getListActionUrl(): string
    {
        return $this->batchUrl->getListActionUrl();
    }

    /**
     * Obtain url for troubleshooting failed batches
     *
     * @return string
     */
    public function getSolveUrl(): string
    {
        return $this->batchUrl->getSolveActionUrl([
            BatchInterface::BATCH_ID => $this->batchProvider->getBatch()->getBatchId(),
        ]);
    }

    /**
     * Get the order view action URL by platform shipment ID.
     *
     * @param string $extShipmentId
     * @return string
     */
    public function getOrderViewUrl($extShipmentId): string
    {
        return $this->urlBuilder->getUrl('temando/order/view', ['shipment_id' => $extShipmentId]);
    }

    /**
     * Render the recipient address.
     *
     * @param DataObject|LocationInterface $location
     * @return string
     */
    public function getShipToAddressHtml(DataObject $location): string
    {
        /** @var LocationInterface $location */
        $shippingAddress = $this->addressFactory->createFromShipmentLocation($location);
        return $this->addressRenderer->getFormattedAddress($shippingAddress);
    }

    /**
     * Obtain the items shipped with the given platform shipment id.
     *
     * @param $extShipmentId
     * @return DataObject[]|ShipmentItemInterface[]
     */
    public function getShipmentItems($extShipmentId): array
    {
        $batch = $this->batchProvider->getBatch();

        $shipments = array_merge($batch->getFailedShipments(), $batch->getIncludedShipments());

        /** @var ShipmentSummaryInterface $shipment */
        foreach ($shipments as $shipment) {
            if ($shipment->getShipmentId() === $extShipmentId) {
                return $shipment->getItems();
            }
        }

        return [];
    }
}
